==> sender_access_list-0.2.5.tgz: sender_access_list/sender_access_list-settings.js <==
/*
 * sender_access_list plugin script
 */

if (window.rcmail) {
	rcmail.addEventListener('init', function(evt) {
		rcmail.register_command('plugin.sender_access_list.addressrule_add', function() {
			var adrTable = rcube_find_object('addressrulestable').tBodies[0];
			var input_accesslist_rule = rcube_find_object('_accesslist_rule');
			var selrule = input_accesslist_rule.selectedIndex;
			var input_accesslist_address = rcube_find_object('_accesslist_address');

			if (selrule == 0) {
				alert(rcmail.gettext('chooselist', 'sender_access_list'));
				input_accesslist_rule.focus();
				return false;
			} else if (selrule > 2) {
				alert(rcmail.gettext('invalidlistno', 'sender_access_list'));
				input_accesslist_rule.focus();
				return false;
			} else if (input_accesslist_address.value.replace(/^\s+|\s+$/g, '') == '') {
				alert(rcmail.gettext('enteraddress', 'sender_access_list'));
				input_accesslist_address.focus();
				return false;
			} else if (!rcube_check_email(input_accesslist_address.value.replace(/^\s+/, '').replace(/[\s,;]+$/, ''), true)) {
				alert(rcmail.gettext('addresserror', 'sender_access_list'));
				input_accesslist_address.focus();
				return false;
			} else {
				var addresses = document.getElementsByName('_access_list_addresses[]');
				var rules = document.getElementsByName('_access_list_rules[]');
				var insHere = false;

				for (var i = 1; i < addresses.length; i++) {
					if (addresses[i].value == input_accesslist_address.value) {
						alert(rcmail.gettext('addressexists', 'sender_access_list'));
						input_accesslist_address.focus();
						return false;
					} else if (addresses[i].value > input_accesslist_address.value) {
						insHere = adrTable.rows[i + 2];
						break;
					}
				}

				rcmail.http_request('plugin.sender_access_list.addressrule_add', '_act='+input_accesslist_rule.selectedIndex+'&_address='+input_accesslist_address.value, rcmail.set_busy(true, 'sender_access_list.addressrule_add'));

				var newNode = adrTable.rows[1].cloneNode(true);
				if (insHere)
					adrTable.insertBefore(newNode, insHere);
				else
					adrTable.appendChild(newNode);

				newNode.style.display = "";
				newNode.cells[0].className = 'rule '+input_accesslist_rule.options[selrule].value;
				newNode.cells[0].innerHTML = rcmail.gettext('addedto', 'sender_access_list')+input_accesslist_rule.options[selrule].text;
				newNode.cells[1].innerHTML = input_accesslist_address.value;

				input_accesslist_rule.selectedIndex = 0;
				input_accesslist_address.value = '';

				adrTable.rows[2].style.display = 'none';
			}

			return(false);
		}, true);

		rcmail.register_command('plugin.sender_access_list.addressrule_del', function(props, obj) {
			var adrTable = rcube_find_object('addressrulestable').tBodies[0];
			var rowidx = obj.parentNode.parentNode.rowIndex;

			if (!confirm(rcmail.gettext('addressdelete', 'sender_access_list'))) return false;

			var addresses = document.getElementsByName('_access_list_addresses[]');

			rcmail.http_request('plugin.sender_access_list.addressrule_del', '_address='+addresses[rowidx - 3].value, rcmail.set_busy(true, 'sender_access_list.addressrule_del'));

			adrTable.deleteRow(rowidx - 1);

			if (addresses.length <= 1) adrTable.rows[2].style.display = '';		// message 'noaddressrules'
		}, true);
	})
}

==> sender_access_list-0.2.7.tgz: sender_access_list/sender_access_list-settings.js <==
/*
 * sender_access_list plugin script
 */

if (window.rcmail) {
	rcmail.addEventListener('init', function(evt) {
		rcmail.register_command('plugin.sender_access_list.addressrule_add', function() {
			var adrTable = rcube_find_object('addressrulestable').tBodies[0];
			var input_accesslist_rule = rcube_find_object('_accesslist_rule');
			var input_accesslist_address = rcube_find_object('_accesslist_address');

			if (input_accesslist_rule.selectedIndex >= 2) {
				alert(rcmail.gettext('invalidlistno', 'sender_access_list'));
				input_accesslist_rule.focus();
				return false;
			} else if (input_accesslist_address.value.replace(/(^\s+|\s+$)/g, '') == '') {
				alert(rcmail.gettext('enteraddress', 'sender_access_list'));
				input_accesslist_address.focus();
				return false;
			} else if (!rcube_check_email(input_accesslist_address.value.replace(/^\s+/, '').replace(/[\s,;]+$/, ''), true)) {
				alert(rcmail.gettext('addresserror', 'sender_access_list'));
				input_accesslist_address.focus();
				return false;
			} else {
				var addresses = document.getElementsByName('_access_list_addresses[]');
				var rules = document.getElementsByName('_access_list_rules[]');
				var insHere = false;

				for (var i = 1; i < addresses.length; i++) {
					if (addresses[i].value == input_accesslist_address.value) {
						alert(rcmail.gettext('addressexists', 'sender_access_list'));
						input_accesslist_address.focus();
						return false;
					} else if (addresses[i].value > input_accesslist_address.value) {
						insHere = adrTable.rows[i + 2];
						break;
					}
				}

				if (
					(input_accesslist_rule.options[input_accesslist_rule.selectedIndex].value == "towhitelist") ||
					(input_accesslist_rule.options[input_accesslist_rule.selectedIndex].value == "toblacklist")
				) {
					rcmail.http_request('plugin.sender_access_list.addressrule_add', '_act='+input_accesslist_rule.options[input_accesslist_rule.selectedIndex].value+'&_address='+input_accesslist_address.value, rcmail.set_busy(true, 'sender_access_list.addressrule_add'));
				} else {
					alert(rcmail.gettext('invalidlistno', 'sender_access_list'));
					input_accesslist_rule.focus();
					return false;
				}

				var newNode = adrTable.rows[1].cloneNode(true);
				if (insHere)
					adrTable.insertBefore(newNode, insHere);
				else
					adrTable.appendChild(newNode);

				newNode.style.display = "";
				newNode.cells[0].innerHTML = input_accesslist_address.value;
				if (input_accesslist_rule.options[input_accesslist_rule.selectedIndex].value == "towhitelist") {
					newNode.cells[1].className = 'ruletype value whitelisted';
					newNode.cells[1].innerHTML = rcmail.gettext("whitelisted", 'sender_access_list');
				}
				if (input_accesslist_rule.options[input_accesslist_rule.selectedIndex].value == "toblacklist") {
					newNode.cells[1].className = 'ruletype value blacklisted';
					newNode.cells[1].innerHTML = rcmail.gettext("blacklisted", 'sender_access_list');
				}

				input_accesslist_rule.selectedIndex = 0;
				input_accesslist_address.value = '';

				adrTable.rows[2].style.display = 'none';
			}

			return(false);
		}, true);

		rcmail.register_command('plugin.sender_access_list.addressrule_del', function(props, obj) {
			var adrTable = rcube_find_object('addressrulestable').tBodies[0];
			var rowidx = obj.parentNode.parentNode.rowIndex;

			if (!confirm(rcmail.gettext('addressdelete', 'sender_access_list'))) return false;

			var addresses = document.getElementsByName('_access_list_addresses[]');

			rcmail.http_request('plugin.sender_access_list.addressrule_del', '_address='+addresses[rowidx - 3].value, rcmail.set_busy(true, 'sender_access_list.addressrule_del'));

			adrTable.deleteRow(rowidx - 1);

			if (addresses.length <= 1) adrTable.rows[2].style.display = '';		// message 'noaddressrules'
		}, true);
	})
}
